summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/debug.cc
diff options
context:
space:
mode:
Diffstat (limited to 'crawl-ref/source/debug.cc')
-rw-r--r--crawl-ref/source/debug.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/crawl-ref/source/debug.cc b/crawl-ref/source/debug.cc
index 9812ae932f..4f0d65189a 100644
--- a/crawl-ref/source/debug.cc
+++ b/crawl-ref/source/debug.cc
@@ -6600,10 +6600,10 @@ void do_crash_dump()
fprintf(file, "dlua stack:" EOL);
print_dlua_stack();
// Lastly try to dump the Lua persistant data and the contents of the Lua
// markers, since actually running Lua code has the greatest chance of
// crashing.
- fprintf(file, "Lua persistant data:" EOL);
+ fprintf(file, "Lua persistent data:" EOL);
fprintf(file, "<<<<<<<<<<<<<<<<<<<<<<" EOL);
_debug_dump_lua_persist(file);
fprintf(file, ">>>>>>>>>>>>>>>>>>>>>>" EOL EOL);
@@ -6600,10 +6600,10 @@ void do_crash_dump()
fprintf(file, "dlua stack:" EOL);
print_dlua_stack();
- // Lastly try to dump the Lua persistant data and the contents of the Lua
+ // Lastly try to dump the Lua persistent data and the contents of the Lua
// markers, since actually running Lua code has the greatest chance of
// crashing.